@@ -12,9 +12,10 @@ from databroker._core import register_builtin_handlers
 from databroker.assets.handlers import HandlerBase
 
 import logging
+
 logger = logging.getLogger(__name__)
 
-db = Broker.named('tes')
+db = Broker.named("tes")
 try:
     register_builtin_handlers(db.reg)
 except Exception as ex:
@@ -22,14 +23,13 @@ except Exception as ex:
 
 
 class BulkXSPRESS(HandlerBase):
-    HANDLER_NAME = 'XPS3_FLY'
+    HANDLER_NAME = "XPS3_FLY"
 
     def __init__(self, resource_fn):
-        self._handle = h5py.File(resource_fn, 'r')
+        self._handle = h5py.File(resource_fn, "r")
 
     def __call__(self):
-        return self._handle['entry/instrument/detector/data'][:]
+        return self._handle["entry/instrument/detector/data"][:]
 
 
-db.reg.register_handler(BulkXSPRESS.HANDLER_NAME, BulkXSPRESS,
-                        overwrite=True)
+db.reg.register_handler(BulkXSPRESS.HANDLER_NAME, BulkXSPRESS, overwrite=True)
