@@ -486,7 +486,8 @@ class ModelWidget(FormBaseWidget):
 
     def pb_save_elines_clicked(self):
         current_dir = self.gpc.get_current_working_directory()
-        fln = os.path.join(current_dir, "model_parameters.json")
+        scan_id = self.gpc.get_metadata_scan_id()
+        fln = os.path.join(current_dir, f"pyxrf_model_parameters_{scan_id}.json")
         file_name = QFileDialog.getSaveFileName(
             self, "Select File to Save Model Parameters", fln, "JSON (*.json);; All (*)"
         )
@@ -540,16 +541,16 @@ class ModelWidget(FormBaseWidget):
 
     def pb_save_spectrum_clicked(self):
         current_dir = self.gpc.get_current_working_directory()
-        dir = QFileDialog.getExistingDirectory(
+        directory = QFileDialog.getExistingDirectory(
             self,
             "Select Directory to Save Spectrum/Fit",
             current_dir,
             QFileDialog.ShowDirsOnly | QFileDialog.DontResolveSymlinks,
         )
-        if dir:
+        if directory:
             try:
-                self.gpc.save_spectrum(dir, save_fit=self._fit_available)
-                logger.debug(f"Spectrum/Fit is saved to directory {dir}")
+                self.gpc.save_spectrum(directory, save_fit=self._fit_available)
+                logger.debug(f"Spectrum/Fit is saved to directory {directory}")
             except Exception as ex:
                 msg = str(ex)
                 msgbox = QMessageBox(QMessageBox.Critical, "Error", msg, QMessageBox.Ok, parent=self)
